==> kpogre-1.2.7.tar.gz: kpogre-1.2.7/kpogre/Wizards/kpg5stepswizard.cpp <==
//
// C++ Implementation: %{MODULE}
//
// Description:
//
//
// Author: %{AUTHOR} <%{EMAIL}>, (C) %{YEAR}
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpg5stepswizard.h"

// include files for KDE
#include <kdebug.h>
#include <ktextedit.h>
#include <kcursor.h>

// application specific includes
#include "../kpogre.h"
#include "../kpgconfiguration.h"
#include "../kpgsqleditorsettings.h"
#include "../kpgsyntaxhighlighter.h"
#include "../DbObjects/kpgconnection.h"

KPG5StepsWizard::KPG5StepsWizard(QWidget *parent, const char *name)
 : KPG5StepsWizardBase(parent, name)
{
  m_pConnection = 0;
  m_pSyntaxHighlighter = new KPGSyntaxHighlighter(m_pTextEditSQL);
  
  m_pSyntaxHighlighter->setColorDefaultText( KPoGreApp::configuration()->sqleditor()->colorDefaultText() );
  m_pSyntaxHighlighter->setColorKeyWords( KPoGreApp::configuration()->sqleditor()->colorKeyWords() );
  m_pSyntaxHighlighter->setColorDataTypes( KPoGreApp::configuration()->sqleditor()->colorDataTypes() );
  m_pSyntaxHighlighter->setColorOperators( KPoGreApp::configuration()->sqleditor()->colorOperators() );
  m_pSyntaxHighlighter->setColorQuotedStrings( KPoGreApp::configuration()->sqleditor()->colorQuotedStrings() );
  m_pSyntaxHighlighter->setColorNumbers( KPoGreApp::configuration()->sqleditor()->colorNumbers() );
  m_pSyntaxHighlighter->setColorComments( KPoGreApp::configuration()->sqleditor()->colorComments() );
  
  m_pSyntaxHighlighter->rehighlight();
    
  setNextEnabled(WizardPage1, false);
  setNextEnabled(WizardPage2, false);
}


KPG5StepsWizard::~KPG5StepsWizard()
{
  delete m_pSyntaxHighlighter;
}

// Set connection for wizard operation
void KPG5StepsWizard::setConnection(KPGConnection * pConnection)
{
  m_pConnection = pConnection;
}

// Run SQL query - as final Wizard operation
void KPG5StepsWizard::runQuery(bool bWithTransaction) 
{ 
   // Run SQL statement
   if(m_pConnection == 0)
    {
      kdError() << "KPG5StepsWizard::runQuery - Database not connected to server !" << endl;
      m_pTextEditResult->setText("Database not connected to server !");
    }
    else
    { 
      try
      { 
        setCursor(KCursor::waitCursor());
        
        pqxx::result R = m_pConnection->runQuery(m_pTextEditSQL->text(), bWithTransaction ? KPGConnection::eTransNormal : KPGConnection::eTransNone);
        
        if(m_pConnection->notifications().count() > 0)
        {
           m_pTextEditResult->setText(m_pConnection->notifications().join("") + i18n("\nOperation successfull"));
           m_pConnection->clearNotifications();
        }
        else
          m_pTextEditResult->setText(i18n("Operation successfull"));
        
        setFinishEnabled(WizardPage5, true);
        setCursor(KCursor::arrowCursor());
      }
      catch (const std::exception &e)
      {
        m_pTextEditResult->setText(e.what());
        setCursor(KCursor::arrowCursor());
      } 
    }
}

// Enable/disable next button for 1st page
void KPG5StepsWizard::slotEnableNextButton1(bool bEnable)
{
    setNextEnabled(WizardPage1, bEnable);
}

// Enable/disable next button for 2nd page
void KPG5StepsWizard::slotEnableNextButton2(bool bEnable)
{
    setNextEnabled(WizardPage2, bEnable);
}

// Enable/disable next button for 3rd page
void KPG5StepsWizard::slotEnableNextButton3(bool bEnable)
{
    setNextEnabled(WizardPage3, bEnable);
}

#include "kpg5stepswizard.moc"

==> kpogre-1.5.2.tar.gz: kpogre-1.5.2/kpogre/Wizards/kpg5stepswizard.cpp <==
//
// C++ Implementation: %{MODULE}
//
// Description:
//
//
// Author: %{AUTHOR} <%{EMAIL}>, (C) %{YEAR}
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpg5stepswizard.h"

// include files for KDE
#include <kdebug.h>
#include <ktextedit.h>
#include <kcursor.h>

// application specific includes
#include "../kpogreview.h"
#include "../kpgconfiguration.h"
#include "../QueryResult/kpgsqleditorsettings.h"
#include "../QueryResult/kpgsyntaxhighlighter.h"
#include "../DbObjects/kpgconnection.h"

KPG5StepsWizard::KPG5StepsWizard(QWidget *parent, const char *name)
 : KPG5StepsWizardBase(parent, name)
{
  m_pConnection = 0;
  m_pTextEditSQL->setFont( KPoGreView::configuration()->sqleditor()->font() );
  m_pSyntaxHighlighter = new KPGSyntaxHighlighter(m_pTextEditSQL);
  
  m_pSyntaxHighlighter->setColorDefaultText( KPoGreView::configuration()->sqleditor()->colorDefaultText() );
  m_pSyntaxHighlighter->setColorKeyWords( KPoGreView::configuration()->sqleditor()->colorKeyWords() );
  m_pSyntaxHighlighter->setColorDataTypes( KPoGreView::configuration()->sqleditor()->colorDataTypes() );
  m_pSyntaxHighlighter->setColorOperators( KPoGreView::configuration()->sqleditor()->colorOperators() );
  m_pSyntaxHighlighter->setColorQuotedStrings( KPoGreView::configuration()->sqleditor()->colorQuotedStrings() );
  m_pSyntaxHighlighter->setColorNumbers( KPoGreView::configuration()->sqleditor()->colorNumbers() );
  m_pSyntaxHighlighter->setColorComments( KPoGreView::configuration()->sqleditor()->colorComments() );
  
  m_pSyntaxHighlighter->rehighlight();
    
  setNextEnabled(WizardPage1, false);
  setNextEnabled(WizardPage2, false);
}


KPG5StepsWizard::~KPG5StepsWizard()
{
  delete m_pSyntaxHighlighter;
}

// Set connection for wizard operation
void KPG5StepsWizard::setConnection(KPGConnection * pConnection)
{
  m_pConnection = pConnection;
}

// Run SQL query - as final Wizard operation
void KPG5StepsWizard::runQuery(bool bWithTransaction) 
{ 
   // Run SQL statement
   if(m_pConnection == 0)
    {
      kdError() << k_funcinfo << " Database not connected to server !" << endl;
      m_pTextEditResult->setText("Database not connected to server !");
    }
    else
    { 
      try
      { 
        setCursor(KCursor::waitCursor());
        
        pqxx::result R = m_pConnection->runQuery(m_pTextEditSQL->text(), bWithTransaction ? KPGConnection::eTransNormal : KPGConnection::eTransNone);
        
        if(m_pConnection->notifications().count() > 0)
        {
           m_pTextEditResult->setText(m_pConnection->notifications().join("") + i18n("\nOperation successfull"));
           m_pConnection->clearNotifications();
        }
        else
          m_pTextEditResult->setText(i18n("Operation successfull"));
        
        setFinishEnabled(WizardPage5, true);
        setCursor(KCursor::arrowCursor());
      }
      catch (const std::exception &e)
      {
        m_pTextEditResult->setText(e.what());
        setCursor(KCursor::arrowCursor());
      } 
    }
}

// Enable/disable next button for 1st page
void KPG5StepsWizard::slotEnableNextButton1(bool bEnable)
{
    setNextEnabled(WizardPage1, bEnable);
}

// Enable/disable next button for 2nd page
void KPG5StepsWizard::slotEnableNextButton2(bool bEnable)
{
    setNextEnabled(WizardPage2, bEnable);
}

// Enable/disable next button for 3rd page
void KPG5StepsWizard::slotEnableNextButton3(bool bEnable)
{
    setNextEnabled(WizardPage3, bEnable);
}

#include "kpg5stepswizard.moc"
